@@ -5,7 +5,7 @@ package Lingua::Word::Parser;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Bit::Vector;
 use DBI;
@@ -139,12 +139,13 @@ sub knowns {
                 defn => $i->{defn},
                 mask => $mask,
             };
+
             # Save the relationship between mask and id.
             $self->{masks}{$mask} = $id++;
         }
     }
 
-    return $self->{known}, $self->{masks};
+    return $self->{known};
 }
 
 
@@ -381,7 +382,7 @@ Lingua::Word::Parser - Parse a word into known and unknown parts
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -399,13 +400,12 @@ version 0.06
     dbpass => 's3kr1+',
  );
 
- my ($known, $masks) = $p->knowns;
- my $combos  = $p->power;
- my $parts   = $p->score_parts;
- my $scored  = $p->score;
+ my $known  = $p->knowns;
+ my $combos = $p->power;
+ my $parts  = $p->score_parts;
 
- # The best guess is the last sorted score-set:
- warn Dumper $scored->{ [ sort keys %$scored ]->[-1] };
+ # The best guess is the last sorted scored set:
+ print Dumper $scored->{ [ sort keys %$scored ]->[-1] };
 
 =head1 DESCRIPTION
 
@@ -419,6 +419,8 @@ the form:
  (?<=\w)o(?=\w) combining
  (?<=\w)tic     possessing
 
+Please see the included F<eg/lexicon.dat> file.
+
 A database lexicon must have records of the form:
 
          affix     definition
@@ -428,6 +430,8 @@ A database lexicon must have records of the form:
   (?<=\w)o(?=\w)   combining
   (?<=\w)tic       possessing
 
+Please see the included F<eg/word_part.sql> file.
+
 =head1 METHODS
 
 =head2 new()
@@ -447,11 +451,16 @@ Arguments and defaults:
 
 =head2 knowns()
 
+ my $known = $p->knowns;
+
 Find the known word parts and their bitstring masks.
 
 =head2 power()
 
-Find the powerset of non-overlapping known word parts.
+ my $combos = $p->power();
+
+Find the set of non-overlapping known word parts by considering the power set of
+all masks.
 
 =head2 score()
 
